@@ -1,5 +1,5 @@
 from ast import Expression
-from typing import Any, Dict, List, Union
+from typing import List, Union
 
 from django.contrib.gis.db import models
 from django.db.models import Func, Value, F
